==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/sr-CS/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Ovaj korisnik može da se uloguje',
    'activated_disabled_help_text' => 'Ne možete da menjate status aktivacije za sopstveni nalog.',
    'assets_user'       => 'Imovina dodijeljena za :name',
    'bulk_update_warn'	=> 'Nameravate uređivati ​​svojstva korisnika :user_count users. Imajte na umu da ne možete menjati vlastite korisničke atribute pomoću ovog obrasca i morati sami uređivati ​​vlastiti nalog pojedinačno.',
    'bulk_update_help'	=> 'Ovaj vam obrazac omogućava ažuriranje više korisnika odjednom. Popunite polja koja su vam potrebna za promjenu. Sva polja koja su ostala prazna će ostati nepromenjena.',
    'current_assets'    => 'Imovina dodeljena ovom koriniku',
    'clone'             => 'Kloniraj korisnika',
    'contact_user'      => 'Kontakt :name',
    'edit'              => 'Edit User',
    'filetype_info'     => 'Dopuštene vrste datoteka su png, gif, jpg, jpeg, doc, docx, pdf, txt, zip i rar.',
    'history_user'      => 'Istorija za :name',
    'info'				=> 'Info',
    'restore_user'		=> 'Kliknite ovdje da biste ih vratili.',
    'last_login'        => 'Poslednja prijava',
    'ldap_config_text'  => 'Postavke LDAP konfiguracije mogu se pronaći u Administrator> Postavke. Odabrana lokacija (opcionalno) će biti podešena za sve importovane korisnike.',
    'print_assigned'    => 'Print All Assigned',
    'email_assigned'    => 'Pošalji spisak svega zaduženog',
    'user_notified'     => 'Korisniku je poslata poruka sa spiskom svega zaduženog na njegovo ime.',
    'auto_assign_label' => 'Uvrsti ovog korisnika u automatskom dodeljivanju kvalifikovanih licenci',
    'auto_assign_help'  => 'Preskoči ovog korisnika u automatskoj dodeli licenci',
    'software_user'     => 'Software Checked out to :name',
    'send_email_help'   => 'Morate da navedete adresu e-pošte za ovog korisnika da biste mu poslali akreditive. Slanje akreditiva e-poštom se može izvršiti samo prilikom kreiranja korisnika. Lozinke se čuvaju u jednosmernom hešu i ne mogu se preuzeti kada su sačuvane.',
    'view_user'         => 'Prikaži korisnika :name',
    'usercsv'           => 'CSV file',
    'two_factor_admin_optin_help' => 'Your current admin settings allow selective enforcement of two-factor authentication.  ',
    'two_factor_enrolled' => '2FA uređaj je upisan ',
    'two_factor_active'   => '2FA uređaj je aktivan ',
    'user_deactivated'  => 'Korisnik ne može da se prijavi',
    'user_activated'  => 'Korisnik može da se prijavi',
    'activation_status_warning' => 'Ne menjajte status aktivacije',
    'group_memberships_helpblock' => 'Samo superadministratori mogu da uređuju članstva u grupama.',
    'superadmin_permission_warning' => 'Samo superadministratori mogu odobriti korisniku superadministratorski pristup.',
    'admin_permission_warning' => 'Samo korisnici sa administratorskim pravima ili većim mogu odobriti korisniku administratorski pristup.',
    'remove_group_memberships' => 'Uklonite članstvo u grupi',
    'warning_deletion_information' => 'Potrebno je da obeležite SVE stavke navedene ispod počevši od stavke :broj korisnika. Imena superadministratora su istaknuta crvenom bojom.',
    'update_user_assets_status' => 'Uredi svu imovinu ovih korisnika u ovaj status',
    'checkin_user_properties' => 'Proverite sva svojstva povezana sa ovim korisnicima',
    'remote_label'   => 'Ovo je udaljeni korisnik',
    'remote'   => 'Daljinski',
    'remote_help' => 'Ovo može biti korisno ako treba da filtrirate prema udaljenim korisnicima koji nikada ili retko dolaze na vaše fizičke lokacije.',
    'not_remote_label' => 'Ovo nije udaljeni korisnik',
    'vip_label' => 'VIP Korisnik',
    'vip_help' => 'Ovo može pomoći da označite važne ljude u vašoj organizaciji ako bi ste želeli da njima upravljate na posebne načine.',
    'create_user' => 'Kreiraj korisnika',
    'create_user_page_explanation' => 'Ovo su informacije o nalogu koje će te koristiti da pristupite sajtu po prvi put.',
    'email_credentials' => 'Akreditivi za Email',
    'email_credentials_text' => 'Pošalji moje akreditive na adresu elektornske pošte navedene iznad',
    'next_save_user' => 'Sledeće: Sačuvaj korisnika',
    'all_assigned_list_generation' => 'Generisano:',
    'email_user_creds_on_create' => 'Poslati ovom korisniku e-poruku sa njegovim kredencijalima?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/sr-CS/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Ovaj korisnik može da se uloguje',
    'activated_disabled_help_text' => 'Ne možete da menjate status aktivacije za sopstveni nalog.',
    'assets_user'       => 'Imovina dodijeljena za :name',
    'bulk_update_warn'	=> 'Nameravate uređivati ​​svojstva korisnika :user_count users. Imajte na umu da ne možete menjati vlastite korisničke atribute pomoću ovog obrasca i morati sami uređivati ​​vlastiti nalog pojedinačno.',
    'bulk_update_help'	=> 'Ovaj vam obrazac omogućava ažuriranje više korisnika odjednom. Popunite polja koja su vam potrebna za promjenu. Sva polja koja su ostala prazna će ostati nepromenjena.',
    'current_assets'    => 'Imovina dodeljena ovom koriniku',
    'clone'             => 'Kloniraj korisnika',
    'contact_user'      => 'Kontakt :name',
    'edit'              => 'Edit User',
    'filetype_info'     => 'Dopuštene vrste datoteka su png, gif, jpg, jpeg, doc, docx, pdf, txt, zip i rar.',
    'history_user'      => 'Istorija za :name',
    'info'				=> 'Info',
    'restore_user'		=> 'Kliknite ovdje da biste ih vratili.',
    'last_login'        => 'Poslednja prijava',
    'ldap_config_text'  => 'Postavke LDAP konfiguracije mogu se pronaći u Administrator> Postavke. Odabrana lokacija (opcionalno) će biti podešena za sve importovane korisnike.',
    'print_assigned'    => 'Print All Assigned',
    'email_assigned'    => 'Pošalji spisak svega zaduženog',
    'user_notified'     => 'Korisniku je poslata poruka sa spiskom svega zaduženog na njegovo ime.',
    'users_notified'    => 'Korisniku je poslata e-poruka sa spiskom trenutno zaduženih stavki.|:count korisnicima je poslata e-poruka sa spiskom trenutno zaduženih stavki.',
    'users_notified_warning' => ':count korisnicima je poslata e-poruka sa spiskom trenutno zaduženih stavki, međutim :no_email korisnika nemaju adresu e-pošte pa im poruka nije mogla biti poslata.|:count korisnicima je poslata e-poruka sa spiskom trenutno zaduženih stavki, međutim :no_email korisnika nemaju adresu e-pošte pa im poruka nije mogla biti poslata.',
    'auto_assign_label' => 'Uvrsti ovog korisnika u automatskom dodeljivanju kvalifikovanih licenci',
    'auto_assign_help'  => 'Preskoči ovog korisnika u automatskoj dodeli licenci',
    'software_user'     => 'Software Checked out to :name',
    'send_email_help'   => 'Morate da navedete adresu e-pošte za ovog korisnika da biste mu poslali akreditive. Slanje akreditiva e-poštom se može izvršiti samo prilikom kreiranja korisnika. Lozinke se čuvaju u jednosmernom hešu i ne mogu se preuzeti kada su sačuvane.',
    'view_user'         => 'Prikaži korisnika :name',
    'usercsv'           => 'CSV file',
    'two_factor_admin_optin_help' => 'Your current admin settings allow selective enforcement of two-factor authentication.  ',
    'two_factor_enrolled' => '2FA uređaj je upisan ',
    'two_factor_active'   => '2FA uređaj je aktivan ',
    'user_deactivated'  => 'Korisnik ne može da se prijavi',
    'user_activated'  => 'Korisnik može da se prijavi',
    'activation_status_warning' => 'Ne menjajte status aktivacije',
    'group_memberships_helpblock' => 'Samo superadministratori mogu da uređuju članstva u grupama.',
    'superadmin_permission_warning' => 'Samo superadministratori mogu odobriti korisniku superadministratorski pristup.',
    'admin_permission_warning' => 'Samo korisnici sa administratorskim pravima ili većim mogu odobriti korisniku administratorski pristup.',
    'remove_group_memberships' => 'Uklonite članstvo u grupi',
    'warning_deletion_information' => 'Potrebno je da obeležite SVE stavke navedene ispod počevši od stavke :broj korisnika. Imena superadministratora su istaknuta crvenom bojom.',
    'update_user_assets_status' => 'Uredi svu imovinu ovih korisnika u ovaj status',
    'checkin_user_properties' => 'Proverite sva svojstva povezana sa ovim korisnicima',
    'remote_label'   => 'Ovo je udaljeni korisnik',
    'remote'   => 'Daljinski',
    'remote_help' => 'Ovo može biti korisno ako treba da filtrirate prema udaljenim korisnicima koji nikada ili retko dolaze na vaše fizičke lokacije.',
    'not_remote_label' => 'Ovo nije udaljeni korisnik',
    'vip_label' => 'VIP Korisnik',
    'vip_help' => 'Ovo može pomoći da označite važne ljude u vašoj organizaciji ako bi ste želeli da njima upravljate na posebne načine.',
    'create_user' => 'Kreiraj korisnika',
    'create_user_page_explanation' => 'Ovo su informacije o nalogu koje će te koristiti da pristupite sajtu po prvi put.',
    'email_credentials' => 'Akreditivi za Email',
    'email_credentials_text' => 'Pošalji moje akreditive na adresu elektornske pošte navedene iznad',
    'next_save_user' => 'Sledeće: Sačuvaj korisnika',
    'all_assigned_list_generation' => 'Generisano:',
    'email_user_creds_on_create' => 'Poslati ovom korisniku e-poruku sa njegovim kredencijalima?',
];
